@@ -1,15 +1,14 @@
-from collections import Counter
 import textwrap
-from typing import overload
-from typing import Optional, Union as _UnionT
-from typing import Dict, List, Set, Tuple
-from typing import Iterator, Mapping, Sequence
 import warnings
+from collections import Counter
+from collections.abc import Iterator, Mapping, Sequence
+from typing import Optional, overload
+from typing import Union as _UnionT
 
 
-class ImportedNamespaces(object):
+class ImportedNamespaces:
     def __init__(self) -> None:
-        self.data: Dict[str, Optional[str]] = {}
+        self.data: dict[str, Optional[str]] = {}
 
     @overload
     def add(self, modulename: str, /) -> None: ...
@@ -59,7 +58,7 @@ class ImportedNamespaces(object):
             from_, import_ = name1, name2
         self.data[import_] = from_
 
-    def __contains__(self, item: _UnionT[str, Tuple[str, str]]) -> bool:
+    def __contains__(self, item: _UnionT[str, tuple[str, str]]) -> bool:
         """Returns item has already added.
 
         Examples:
@@ -85,7 +84,7 @@ class ImportedNamespaces(object):
             return self.data[import_] == from_
         return False
 
-    def get_symbols(self) -> Set[str]:
+    def get_symbols(self) -> set[str]:
         names = set()
         for key, val in self.data.items():
             if val is None or key == "*":
@@ -106,8 +105,8 @@ class ImportedNamespaces(object):
         return code
 
     def getvalue(self) -> str:
-        ns: Dict[str, Optional[Set[str]]] = {}
-        lines: List[str] = []
+        ns: dict[str, Optional[set[str]]] = {}
+        lines: list[str] = []
         for key, val in self.data.items():
             if val is None:
                 ns[key] = val
@@ -124,9 +123,9 @@ class ImportedNamespaces(object):
         return "\n".join(lines)
 
 
-class DeclaredNamespaces(object):
+class DeclaredNamespaces:
     def __init__(self) -> None:
-        self.data: Dict[Tuple[str, str], Optional[str]] = {}
+        self.data: dict[tuple[str, str], Optional[str]] = {}
 
     def add(self, alias: str, definition: str, comment: Optional[str] = None) -> None:
         """Adds a namespace will be declared.
@@ -144,7 +143,7 @@ class DeclaredNamespaces(object):
         """
         self.data[(alias, definition)] = comment
 
-    def get_symbols(self) -> Set[str]:
+    def get_symbols(self) -> set[str]:
         names = set()
         for alias, _ in self.data.keys():
             names.add(alias)
@@ -160,9 +159,9 @@ class DeclaredNamespaces(object):
         return "\n".join(lines)
 
 
-class EnumerationNamespaces(object):
+class EnumerationNamespaces:
     def __init__(self) -> None:
-        self.data: Dict[str, List[Tuple[str, int]]] = {}
+        self.data: dict[str, list[tuple[str, int]]] = {}
 
     def add(self, enum_name: str, member_name: str, value: int) -> None:
         """Adds a namespace will be enumeration and its member.
@@ -228,12 +227,12 @@ class EnumerationNamespaces(object):
     def __bool__(self) -> bool:
         return bool(self.data)
 
-    def get_symbols(self) -> Set[str]:
+    def get_symbols(self) -> set[str]:
         return set(self.data)
 
     def _iter_members(
-        self, members: Sequence[Tuple[str, int]]
-    ) -> Iterator[Tuple[str, bool, int]]:
+        self, members: Sequence[tuple[str, int]]
+    ) -> Iterator[tuple[str, bool, int]]:
         key_counter = Counter(m for m, _ in members)
         decrementee = dict(key_counter)  # shallow copy
         for name, value in members:
@@ -241,7 +240,7 @@ class EnumerationNamespaces(object):
             # definition, is_dupl, rest_dupl_count
             yield f"{name} = {value}", key_counter[name] > 1, decrementee[name]
 
-    def _iter_items(self) -> Iterator[Tuple[str, Iterator[Tuple[str, bool, int]]]]:
+    def _iter_items(self) -> Iterator[tuple[str, Iterator[tuple[str, bool, int]]]]:
         for name, members in self.data.items():
             yield name, self._iter_members(members)
 
